@@ -43,14 +43,20 @@ $(document).ready(function () {
       // add the computed classes and attributes
       class_attr = d["class"].join(" ");
       id_attr = d["id"];
-      $(this).nextUntilWithTextNodes(this.tagName).addBack().wrapAll(`<div id='${id_attr}' class='${class_attr}' />`);
+      
+      untilNodes = `${this.tagName}`
+      for (let hPrev = 1; hPrev < x; hPrev++) {
+        untilNodes += `,.level${hPrev}`
+      }
+
+      $(this).nextUntilWithTextNodes(untilNodes).addBack().wrapAll(`<div id='${id_attr}' class='${class_attr}' />`);
 
       tabNumber += 1;
     });
   }
 
-    // process all pretty-jupyter-token elements
-    $(".pretty-jupyter-token").each(function (i, e) {
+    // process all pj-token elements (pretty-jupyter-token for backwards compatibility)
+    $(".pj-token,.pretty-jupyter-token").each(function (i, e) {
       // if it has tabset, add tabset class to the section
       if ($(this).hasClass("tabset")) {
         $(this).parent().closest(".section").addClass("tabset");
@@ -79,7 +85,7 @@ window.initializeCodeFolding = function(show) {
   var currentIndex = 1;
 
   // select all jupyter code blocks
-  var jupyterCodeBlocks = $('div.pretty-jupyter-input');
+  var jupyterCodeBlocks = $('div.pj-input');
   jupyterCodeBlocks.each(function() {
 
     // create a collapsable div to wrap the code in
@@ -187,10 +193,10 @@ $(document).ready(function () {
 
 // custom post-processing: remove some ugly styles etc 
 $(document).ready(function () {
-  // prettify tables
-  $(".main-container table").addClass("table");
-  $(".main-container table").addClass("table-striped");
-  $("table.dataframe").removeAttr("border");
+  // prettify tables (that aren't ignored)
+  $("table:not(.pj-tab-ignore)").addClass("table");
+  $("table:not(.pj-tab-ignore)").addClass("table-striped");
+  $("table.dataframe:not(.pj-tab-ignore)").removeAttr("border");
 
   // remove useless anchor with useless anchor-link
   $("a.anchor-link").remove();
